<?php

require_once 'modules/billing/models/class.gateway.plugin.php';

class PluginOxapay extends GatewayPlugin
{
    public function getVariables()
    {
        $variables = array (
            lang("Plugin Name") => array (
                "type"          => "hidden",
                "description"   => lang("How CE sees this plugin (not to be confused with the Signup Name)"),
                "value"         => lang("OxaPay")
            ),
            lang("Merchant Key") => array (
                "type"          => "text",
                "description"   => lang("You can find your OxaPay Merchant Key in the settings of your personal account. Read more <a href='https://docs.oxapay.com/integrations/merchant-api'>here</a>"),
                "value"         => ""
            ),
            lang("Signup Name") => array (
                "type"          => "text",
                "description"   => lang("Select the name to display in the signup process for this payment type. Example: eCheck or Credit Card."),
                "value"         => "OxaPay"
            )

        );
        return $variables;
    }

    public function credit($params)
    {
    }

    public function singlepayment($params, $test = false)
    {
        $merchantId = $this->settings->get('plugin_oxapay_Merchant Key');
        $invoiceId = $params['invoiceNumber'];

        if (empty($merchantId)) {
            echo 'You do not have entered Merchant Key';
            exit;
        }
        $data = [
            'merchant' => $merchantId,
            'orderId' => $params['invoiceNumber'],
            'amount' => $params['invoiceTotal'],
            'currency' => $params['userCurrency'],
            'email' => $params['userEmail'],
            'description' => $params['invoiceDescription'],
            'feePaidByPayer'=> 1,
            'callbackUrl' => $params['clientExecURL'] . '/plugins/gateways/oxapay/callback.php',
            'returnUrl' => CE_Lib::getSoftwareURL() . "/index.php?fuse=billing&controller=invoice&view=invoice&id=" . $invoiceId
        ];
    
        $body = json_encode($data, JSON_UNESCAPED_UNICODE);

        $url = "https://api.oxapay.com/merchants/request";

        $ch = curl_init();
        $headers = [
            'Accept: application/json',
            'Content-Type: application/json;charset=UTF-8',
            'Content-Length: ' . strlen($body),
        ];

        curl_setopt_array(
            $ch,
            [
                CURLOPT_URL => $url,
                CURLOPT_HTTPHEADER => $headers,
                CURLOPT_POST => 1,
                CURLOPT_POSTFIELDS => $body,
                CURLOPT_RETURNTRANSFER => 1,
            ]
        );

        $response = curl_exec($ch);
        curl_close($ch);
        $json = json_decode($response, true);


        if ($response === false) {
            echo 'Error encode OxaPay create payment'. curl_error($ch);
            exit;
        }


        if ($json['result'] !== 100 ) {
            if (!empty($json['message'])) {
                echo 'Error OxaPay create payment. Message: ' . $json['message'];
                echo '<br><a href="' . CE_Lib::getSoftwareURL() . '/index.php?fuse=billing&controller=invoice&view=invoice&id=' . $invoiceId . '" style="display: inline-block; text-decoration: none;">
                <button class="app-btns primary" style="background-color: green; color: white; padding: 10px; border: none; cursor: pointer;">
                    Return
                </button>
                </a><br>';
                exit;
            }

        }

        header("location: " . $json['payLink']);
        exit;
    }
}
