<?php
require_once 'modules/admin/models/PluginCallback.php';
require_once 'modules/admin/models/StatusAliasGateway.php' ;
require_once 'modules/billing/models/class.gateway.plugin.php';
require_once 'modules/billing/models/Invoice_EventLog.php';
require_once 'modules/admin/models/Error_EventLog.php';

class PluginOxapayCallback extends PluginCallback
{
    function processCallback()
    {
        $postData = file_get_contents('php://input');
        $data = json_decode($postData, true);
        CE_Lib::log(4, "** WEBHOOK DATA : " . json_encode($data));
        $Merchant = $this->settings->get('plugin_oxapay_Merchant Key');

        if ($data['type'] === 'payment') {
            $apiSecretKey = $Merchant;
        }else {
            http_response_code(400);
            echo 'Invalid data.type';
            exit;
        }

        $hmacHeader = $_SERVER['HTTP_HMAC'];
        $calculatedHmac = hash_hmac('sha512', $postData, $apiSecretKey);

        if ($calculatedHmac === $hmacHeader) {
            $status = $data['status'];
            $invoiceNumber = $data['orderId'];
            $cPlugin = new Plugin($invoiceNumber, "oxapay", $this->user);

            if ('Expired' == $status || 'Failed' == $status ) {
                $transaction = 'Invalid Transaction';
                $cPlugin->PaymentRejected($transaction);
                http_response_code(200);
                echo 'OK';
                exit;
                }   
            elseif ('Paid' == $status) {
                $txid = $data['txID'];
                $invoice_currency = $data['currency'];
                if ($invoice_currency == 'USD'){
                    $amount = $data['price'];
                }
                else{
                    $url = 'https://api.oxapay.com/api/fiats';
                    $options = array(
                        'http' => array(
                            'header' => 'Content-Type: application/json',
                            'method'  => 'POST',
                        ),
                    );
                    $context  = stream_context_create($options);
                    $response = file_get_contents($url, false, $context);
                    $result = json_decode($response, true);          
                    $currency_rate = floatval($result['data'][$invoice_currency]['price']);
                    $amount = floatval($data['price']) / $currency_rate;
                }
                $cPlugin->setAmount($amount);
                $cPlugin->setAction('charge');
                $cPlugin->setTransactionID($txid);
                if ($cPlugin->IsPaid() == 1) {
                    return;
                }
                $transaction = "OxaPay payment of {$amount} has been completed.";
                $cPlugin->PaymentAccepted($amount, $transaction, $invoiceNumber);
            } 
            http_response_code(200);
            echo 'OK';
        } else {
            http_response_code(400);
            echo 'Invalid HMAC signature';
        }

    }
}